summaryrefslogtreecommitdiff
path: root/libgfortran/generated/eoshift1_8.c
diff options
context:
space:
mode:
Diffstat (limited to 'libgfortran/generated/eoshift1_8.c')
-rw-r--r--libgfortran/generated/eoshift1_8.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libgfortran/generated/eoshift1_8.c b/libgfortran/generated/eoshift1_8.c
index 136f5464c17..1f056b36b98 100644
--- a/libgfortran/generated/eoshift1_8.c
+++ b/libgfortran/generated/eoshift1_8.c
@@ -105,8 +105,8 @@ eoshift1 (gfc_array_char * const restrict ret,
GFC_DIMENSION_SET(ret->dim[i], 0, ub, str);
}
- /* internal_malloc_size allocates a single byte for zero size. */
- ret->base_addr = internal_malloc_size (size * arraysize);
+ /* xmalloc allocates a single byte for zero size. */
+ ret->base_addr = xmalloc (size * arraysize);
}
else if (unlikely (compile_options.bounds_check))